from setuptools import setup

setup(
    name="standup_note_taking",
    version="1.0",
    author="Jarod Daws",
    description="Standup is a notes taking tool for your daily standup meetings!",
    packages=["standup"]

)
